import {Component, Prop, Event, EventEmitter, h, Listen} from '@stencil/core';

@Component({
  tag: 'hy-menu-mobile-breadcrumb',
  styleUrl: 'menu-mobile-breadcrumb.scss',
  shadow: false,
})
export class MenuMobileBreadcrumb {
  @Event() removeBreadcrumb: EventEmitter;
  @Prop() bid: string;
  @Prop() isFirst: boolean = false;
  @Prop() label: string;
  @Prop() labelBack: string;
  @Prop() labelFrontPage: string;
  @Prop() logoUrl?: string;

  // Listener for a click. The current breadcrumb will be remove from the list.
  @Listen('handleClick', {capture: true}) handleClick() {
    this.removeBreadcrumb.emit({bid: this.bid});
  }

  render() {
    return this.isFirst ? (
      <a
        aria-label={`${this.labelBack}: ${this.labelFrontPage}`}
        class={'hy-menu-mobile-breadcrumb'}
        href={this.logoUrl}
      >
        <hy-icon icon={'hy-icon-caret-left'} size={12} />
        <span class={'hy-menu-mobile-breadcrumb__label'}>{this.label}</span>
      </a>
    ) : (
      <button
        aria-label={`${this.labelBack}: ${this.label}`}
        class={'hy-menu-mobile-breadcrumb'}
        onClick={() => this.handleClick()}
      >
        <hy-icon icon={'hy-icon-caret-left'} size={12} />
        <span class={'hy-menu-mobile-breadcrumb__label'}>
          {this.label}
          <span class={'hy-menu-mobile-breadcrumb__label__slash'} aria-hidden={'true'}>
            {' '}
            /{' '}
          </span>
        </span>
      </button>
    );
  }
}
