export interface ProcessFlowBoxValue {
  heading: string;
  description: string;
  step: string;
}

import {Component, ComponentInterface, Watch, Prop, h, Element} from '@stencil/core';
import {ProcessFlowBoxVariants} from '../../utils/utils';

@Component({
  tag: 'hy-process',
  styleUrl: 'process.scss',
  shadow: true,
})
export class Process implements ComponentInterface {
  @Element() el: HTMLElement;
  @Prop() headerstyle: string = 'common';
  @Prop() numberTerm: string;
  private _dataItems: ProcessFlowBoxValue[];
  @Prop() dataItems: ProcessFlowBoxValue[] | string;

  @Watch('dataItems')
  arrayDataWatcher(newValue: ProcessFlowBoxValue[] | string) {
    if (typeof newValue === 'string') {
      this._dataItems = JSON.parse(newValue);
    } else {
      this._dataItems = newValue;
    }
  }
  componentWillLoad() {
    this.arrayDataWatcher(this.dataItems);
  }

  componentDidLoad() {
    let hyMainDiv = this.el.closest('.hy-main');
    if (hyMainDiv) {
      if (!hyMainDiv.classList.contains('with-sidebar')) {
        this.headerstyle = 'large';
      }
    }
  }

  render() {
    /*
    - Logic:
    - 3 items: big
    - 4 items: small
    - 5 items: big
    - 6 items: big
    - 7 items: small
    - 8 items: small
    - 9 items: big
    * */
    const bigVariants = [3, 5, 6, 9];
    const processVariant = bigVariants.includes(this._dataItems.length)
      ? ProcessFlowBoxVariants.default
      : ProcessFlowBoxVariants.small;

    const itemsPerRow = processVariant == ProcessFlowBoxVariants.small ? 4 : 3;
    const classAttributes = [processVariant, 'hy-process', `hy-process__${this.headerstyle}`].join(' ');
    const classItem = 'box';
    var stepState;

    return [
      <div class={classAttributes}>
        {this._dataItems.map((x, index) => {
          index % itemsPerRow == 0 ? (stepState = 'first') : (stepState = 'default');
          return (
            <hy-process-flow-box
              class={classItem}
              variant={processVariant}
              box-number={index + 1}
              box-title={x.heading}
              box-description={x.description}
              intermediate-step-title={x.step}
              step-state={stepState}
              number-term={this.numberTerm}
            />
          );
        })}
      </div>,
    ];
  }
}
